@@ -1,10 +1,12 @@
 from typing import Type
+
 from fastapi_amis_admin.amis.components import PageSchema
 from fastapi_amis_admin.amis_admin.admin import AdminApp, ModelAdmin
 from fastapi_amis_admin.crud.utils import schema_create_by_schema
 from starlette.requests import Request
+
 from fastapi_user_auth.admin import UserLoginFormAdmin, GroupAdmin, PermissionAdmin, UserAdmin, \
-    UserRegFormAdmin, RoleAdmin, UserInfoFormAdmin
+    UserRegFormAdmin, RoleAdmin, UserInfoFormAdmin  # noqa F401
 from fastapi_user_auth.auth import AuthRouter
 
 
@@ -24,28 +26,26 @@ class UserAuthApp(AdminApp, AuthRouter):
         AdminApp.__init__(self, app)
         AuthRouter.__init__(self)
         self.UserAdmin.model = self.UserAdmin.model or self.auth.user_model
-        self.UserLoginFormAdmin.schema = self.UserLoginFormAdmin.schema \
-                                         or schema_create_by_schema(self.auth.user_model, 'UserLoginIn',
-                                                                    include={'username', 'password'})
+        self.UserLoginFormAdmin.schema = self.UserLoginFormAdmin.schema or schema_create_by_schema(
+            self.auth.user_model, 'UserLoginIn', include={'username', 'password'})
         self.UserLoginFormAdmin.schema_submit_out = self.UserLoginFormAdmin.schema_submit_out or self.schema_user_login_out
-        self.UserRegFormAdmin.schema = self.UserRegFormAdmin.schema \
-                                       or schema_create_by_schema(self.auth.user_model, 'UserRegIn',
-                                                                  include={'username', 'password', 'email'})
+        self.UserRegFormAdmin.schema = self.UserRegFormAdmin.schema or schema_create_by_schema(
+            self.auth.user_model, 'UserRegIn', include={'username', 'password', 'email'})
         self.UserRegFormAdmin.schema_submit_out = self.UserRegFormAdmin.schema_submit_out or self.schema_user_login_out
-        self.UserInfoFormAdmin.schema = self.UserInfoFormAdmin.schema \
-                                        or schema_create_by_schema(self.auth.user_model, 'UserInfoForm',
-                                                                   exclude={'id', 'username', 'password', 'is_active',
-                                                                            'parent_id', 'point', 'create_time'})
+        self.UserInfoFormAdmin.schema = self.UserInfoFormAdmin.schema or schema_create_by_schema(
+            self.auth.user_model, 'UserInfoForm', exclude={
+                'id', 'username', 'password', 'is_active', 'parent_id', 'point', 'create_time'})
         self.UserInfoFormAdmin.schema_submit_out = self.UserInfoFormAdmin.schema_submit_out or self.schema_user_info
         # register admin
-        self.register_admin(self.UserLoginFormAdmin,
-                            self.UserRegFormAdmin,
-                            self.UserInfoFormAdmin,
-                            self.UserAdmin,
-                            self.RoleAdmin,
-                            self.GroupAdmin,
-                            self.PermissionAdmin
-                            )
+        self.register_admin(
+            self.UserLoginFormAdmin,
+            self.UserRegFormAdmin,
+            self.UserInfoFormAdmin,
+            self.UserAdmin,
+            self.RoleAdmin,
+            self.GroupAdmin,
+            self.PermissionAdmin
+        )
 
     async def has_page_permission(self, request: Request) -> bool:
         return (await super().has_page_permission(request)
